@@ -105,9 +105,7 @@ formats <- function(x) {
   
     for (nm in names(value)) {
       
-      if (is.null(x[[nm]])) 
-        stop(paste("Name not found:", nm))
-      else
+      if (!is.null(x[[nm]])) 
         attr(x[[nm]], "format") <- value[[nm]]
       
     }
